@@ -1,9 +1,11 @@
 package Log::ger::Filter;
 
-our $DATE = '2017-06-26'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-07'; # DATE
+our $DIST = 'Log-ger'; # DIST
+our $VERSION = '0.032'; # VERSION
 
-use parent 'Log::ger::Plugin';
+use parent qw(Log::ger::Plugin);
 
 1;
 # ABSTRACT: Use a filter plugin
@@ -20,23 +22,23 @@ Log::ger::Filter - Use a filter plugin
 
 =head1 VERSION
 
-version 0.008
+version 0.032
 
 =head1 SYNOPSIS
 
 To set globally:
 
  use Log::ger::Filter;
- Log::ger::Filter->set('Foo');
+ Log::ger::Filter->set('Code', code => sub{ ... });
 
 or:
 
- use Log::ger::Filter 'Foo';
+ use Log::ger::Filter 'Code', (code => sub { ... });
 
 To set for current package only:
 
  use Log::ger::Filter;
- Log::ger::Filter->set_for_current_package('Foo');
+ Log::ger::Filter->set_for_current_package('Code', code => sub { ... });
 
 =for Pod::Coverage ^(.+)$
 
@@ -48,13 +50,15 @@ L<Log::ger::Plugin>
 
 L<Log::ger::Format>
 
+L<Log::ger::Layout>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
