@@ -1,7 +1,9 @@
 package Log::ger::Format;
 
-our $DATE = '2020-03-04'; # DATE
-our $VERSION = '0.031'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-07'; # DATE
+our $DIST = 'Log-ger'; # DIST
+our $VERSION = '0.032'; # VERSION
 
 use parent qw(Log::ger::Plugin);
 
@@ -22,7 +24,7 @@ Log::ger::Format - Use a format plugin
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 SYNOPSIS
 
@@ -55,6 +57,8 @@ L<Log::ger::Output>
 
 L<Log::ger::Plugin>
 
+L<Log::ger::Filter>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
