@@ -1,7 +1,9 @@
 package Log::ger::Output::Array;
 
-our $DATE = '2020-03-04'; # DATE
-our $VERSION = '0.031'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-07'; # DATE
+our $DIST = 'Log-ger'; # DIST
+our $VERSION = '0.032'; # VERSION
 
 use strict;
 use warnings;
@@ -13,12 +15,13 @@ sub get_hooks {
 
     return {
         create_log_routine => [
-            __PACKAGE__, 50,
-            sub {
-                my %hook_args = @_;
+            __PACKAGE__, # key
+            50,          # priority
+            sub {        # hook
+                my %hook_args = @_; # see Log::ger::Manual::Internals/"Arguments passed to hook"
 
                 my $logger = sub {
-                    my ($ctx, $msg) = @_;
+                    my ($per_target_conf, $msg, $per_msg_conf) = @_;
                     push @{$conf{array}}, $msg;
                 };
                 [$logger];
@@ -41,7 +44,7 @@ Log::ger::Output::Array - Log to array
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 SYNOPSIS
 
