@@ -1,7 +1,9 @@
 package Log::ger::Output::String;
 
-our $DATE = '2020-03-04'; # DATE
-our $VERSION = '0.031'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-07'; # DATE
+our $DIST = 'Log-ger'; # DIST
+our $VERSION = '0.032'; # VERSION
 
 use strict;
 use warnings;
@@ -17,12 +19,13 @@ sub get_hooks {
 
     return {
         create_log_routine => [
-            __PACKAGE__, 50,
-            sub {
-                my %hook_args = @_;
+            __PACKAGE__, # key
+            50,          # priority
+            sub {        # hook
+                my %hook_args = @_; # see Log::ger::Manual::Internals/"Arguments passed to hook"
                 my $level = $hook_args{level};
                 my $logger = sub {
-                    my $msg = $_[1];
+                    my ($per_target_conf, $msg, $per_msg_conf) = @_;
                     if ($formatter) {
                         $msg = $formatter->($msg);
                     }
@@ -50,7 +53,7 @@ Log::ger::Output::String - Set output to a string
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 SYNOPSIS
 
